@@ -3,6 +3,8 @@ import re
 import logging
 import boto3
 
+from importlib import import_module
+
 from alira.instance import Instance
 from alira.modules.redis import RedisModule
 
@@ -22,7 +24,7 @@ class EmailNotification(RedisModule):
         template_html_filename: str,
         template_text_filename: str,
         redis_server: str = None,
-        filtering_fn: callable = None,
+        filtering: str = None,
         provider=None,
         **kwargs,
     ):
@@ -35,7 +37,7 @@ class EmailNotification(RedisModule):
 
         self.sender = sender
         self.recipients = recipients
-        self.filtering_fn = filtering_fn
+        self.filtering = self._load_function(filtering)
 
         self.template_html_filename = template_html_filename
         self.template_text_filename = template_text_filename
@@ -45,7 +47,7 @@ class EmailNotification(RedisModule):
         self.provider = provider or AwsSesEmailNotification(**kwargs)
 
     def run(self, instance: Instance, **kwargs):
-        if self.filtering_fn and not self.filtering_fn(instance):
+        if self.filtering and not self.filtering(instance):
             logging.info(
                 f"The instance didn't pass the filtering criteria. Instance: {instance}"
             )
@@ -136,6 +138,20 @@ class EmailNotification(RedisModule):
             logging.exception(e)
             return None
 
+    def _load_function(self, function_name: str):
+        if function_name is None:
+            return None
+
+        try:
+            module_path, _, fn_name = function_name.rpartition(".")
+            function = getattr(import_module(module_path), fn_name)
+            logging.info(f"Loaded function {function_name}")
+
+            return function
+        except Exception as e:
+            logging.exception(f"Unable to load function {function_name}", e)
+            return None
+
 
 class AwsSesEmailNotification(object):
     def __init__(
